From ced0a1f2e554224e1f69ce935df4f059c418965c Mon Sep 17 00:00:00 2001
From: Joe Horsnell <github@joehorsnell.com>
Date: Thu, 5 Sep 2019 19:41:27 +0100
Subject: [PATCH] Allow GETOPT to be set externally to improve performance on
 macOS

`brew --prefix <formula>` is a relatively slow operation (order of half a second
or more) and this is not considered a bug (see `Homebrew/brew` issues [3097][1]
and [3327][2]).

The macOS plaform-specific script evaluates `brew --prefix gnu-getopt` each time
`pass` is invoked, which adds a noticeable delay, especially if `pass` is called
a lot of times (eg in a script that iterates over a large number of entries in
a pass store).

This change allows `GETOPT` to be set externally and `pass` will use the value
provided without evaluating the slow `brew` command.

[1]: https://github.com/Homebrew/brew/issues/3097
[2]: https://github.com/Homebrew/brew/issues/3327
---
 src/password-store.sh  | 8 +++++---
 src/platform/darwin.sh | 7 ++++++-
 2 files changed, 11 insertions(+), 4 deletions(-)

diff --git a/src/password-store.sh b/src/password-store.sh
index 1d119f2..d4f12af 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -239,12 +239,14 @@ tmpdir() {
 	fi
 
 }
-GETOPT="getopt"
-SHRED="shred -f -z"
-BASE64="base64"
 
 source "$(dirname "$0")/platform/$(uname | cut -d _ -f 1 | tr '[:upper:]' '[:lower:]').sh" 2>/dev/null # PLATFORM_FUNCTION_FILE
 
+# Set env var defaults if not already provided externally, or set by platform-specific script above
+GETOPT="${GETOPT:-getopt}"
+SHRED="${SHRED:-shred -f -z}"
+BASE64="${BASE64:-base64}"
+
 #
 # END platform definable
 #
diff --git a/src/platform/darwin.sh b/src/platform/darwin.sh
index 342ecce..6f07e6b 100644
--- a/src/platform/darwin.sh
+++ b/src/platform/darwin.sh
@@ -43,6 +43,11 @@ qrcode() {
 	fi
 }
 
-GETOPT="$(brew --prefix gnu-getopt 2>/dev/null || { which port &>/dev/null && echo /opt/local; } || echo /usr/local)/bin/getopt"
+getopt_path() {
+	"$(brew --prefix gnu-getopt 2>/dev/null || { which port &>/dev/null && echo /opt/local; } || echo /usr/local)/bin/getopt"
+}
+
+GETOPT="${GETOPT:-`getopt_path`}"
+
 SHRED="srm -f -z"
 BASE64="openssl base64"
-- 
2.22.0

